@@ -55,6 +55,10 @@ def _assert_is_numeric(*values):
 	if not all(map(is_numeric, values)):
 		raise errors.EvaluationError('data type mismatch (not a numeric value)')
 
+def _assert_is_string(*values):
+	if not all(map(isinstance, values, [str])):
+		raise errors.EvaluationError('data type mismatch (not a string value)')
+
 def _is_reduced(*values):
 	"""
 	Check if the ast expression *value* is a literal expression and if it is a compound datatype, that all of it's
@@ -125,6 +129,13 @@ class ExpressionBase(ASTNodeBase):
 	def __repr__(self):
 		return "<{0} >".format(self.__class__.__name__)
 
+	def _new_value(self, *args, **kwargs):
+		# perform a context aware load of value
+		value = coerce_value(*args, **kwargs)
+		if isinstance(value, datetime.datetime) and value.tzinfo is None:
+			value = value.replace(tzinfo=self.context.default_timezone)
+		return value
+
 class LiteralExpressionBase(ExpressionBase):
 	"""A base class for representing literal values from the grammar text."""
 	__slots__ = ('value',)
@@ -359,8 +370,29 @@ class LeftOperatorRightExpressionBase(ExpressionBase):
 		digraph.edge(str(id(self)), str(id(self.left)), label='left')
 		digraph.edge(str(id(self)), str(id(self.right)), label='right')
 
+class AddExpression(LeftOperatorRightExpressionBase):
+	"""A class for representing addition expressions from the grammar text."""
+	compatible_types = (DataType.FLOAT,DataType.STRING)
+	result_type = DataType.UNDEFINED
+
+	def __init__(self, *args, **kwargs):
+		super(AddExpression, self).__init__(*args, **kwargs)
+		if self.left.result_type != DataType.UNDEFINED and self.right.result_type != DataType.UNDEFINED:
+			if self.left.result_type != self.right.result_type:
+				raise errors.EvaluationError('data type mismatch')
+			self.result_type = self.left.result_type
+
+	def _op_add(self, thing):
+		left_value = self.left.evaluate(thing)
+		right_value = self.right.evaluate(thing)
+		if isinstance(left_value, str) or isinstance(right_value, str):
+			_assert_is_string(left_value, right_value)
+		else:
+			_assert_is_numeric(left_value, right_value)
+		return operator.add(left_value, right_value)
+
 class ArithmeticExpression(LeftOperatorRightExpressionBase):
-	"""A class for representing arithmetic expressions from the grammar text such as addition and subtraction."""
+	"""A class for representing arithmetic expressions from the grammar text such as subtraction and division."""
 	compatible_types = (DataType.FLOAT,)
 	result_type = DataType.FLOAT
 	def __op_arithmetic(self, op, thing):
@@ -370,7 +402,6 @@ class ArithmeticExpression(LeftOperatorRightExpressionBase):
 		_assert_is_numeric(right_value)
 		return op(left_value, right_value)
 
-	_op_add  = functools.partialmethod(__op_arithmetic, operator.add)
 	_op_sub  = functools.partialmethod(__op_arithmetic, operator.sub)
 	_op_fdiv = functools.partialmethod(__op_arithmetic, operator.floordiv)
 	_op_tdiv = functools.partialmethod(__op_arithmetic, operator.truediv)
@@ -678,7 +709,7 @@ class GetAttributeExpression(ExpressionBase):
 		except errors.AttributeResolutionError as error:
 			attribute_error = error
 		else:
-			return coerce_value(value, verify_type=False)
+			return self._new_value(value, verify_type=False)
 
 		try:
 			value = self.context.resolve(resolved_obj, self.name)
@@ -692,7 +723,7 @@ class GetAttributeExpression(ExpressionBase):
 				attribute_error.suggestion = suggestion
 				raise attribute_error from None
 			value = default_value
-		return coerce_value(value, verify_type=False)
+		return self._new_value(value, verify_type=False)
 
 	def reduce(self):
 		if not _is_reduced(self.object):
@@ -766,7 +797,7 @@ class GetItemExpression(ExpressionBase):
 			if self.safe:
 				return None
 			raise errors.LookupError(resolved_obj, resolved_item)
-		return coerce_value(value, verify_type=False)
+		return self._new_value(value, verify_type=False)
 
 	def reduce(self):
 		if isinstance(self.container.result_type, DataType.MAPPING.__class__):
@@ -891,9 +922,7 @@ class SymbolExpression(ExpressionBase):
 			if default_value is errors.UNDEFINED:
 				raise
 			value = default_value
-		value = coerce_value(value, verify_type=False)
-		if isinstance(value, datetime.datetime) and value.tzinfo is None:
-			value = value.replace(tzinfo=self.context.default_timezone)
+		value = self._new_value(value, verify_type=False)
 
 		# if the expected result type is undefined, return the value
 		if self.result_type == DataType.UNDEFINED:
